@@ -9,7 +9,7 @@ test_relop_orderby <- function() {
      3L , "c" )
  rquery_pipeline <- local_td(dL) %.>%
    orderby(., "y")
- ex_data_table(rquery_pipeline)[]
+ ex_data_table(rquery_pipeline)
 
  invisible(NULL)
 
