@@ -8,7 +8,7 @@ test_relop_rename_columns <- function() {
      3L , "c" )
  rquery_pipeline <- local_td(dL) %.>%
    rename_columns(., c("x" = "y", "y" = "x"))
- ex_data_table(rquery_pipeline)[]
+ ex_data_table(rquery_pipeline)
 
  invisible(NULL)
 }
